==> libreoffice-fresh-sdk-25.2.3-4-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel =
[
    [ "UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Orientation", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#af0ee8cde7520951ddb159c25b871f626", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "Repeat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a5129b8c2bd73916407e626738bd0136b", null ],
    [ "RepeatDelay", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a4e2dfbf3068c08b49a036a8490722569", null ],
    [ "SpinIncrement", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a854bc2fd59eb64624028d76321994d70", null ],
    [ "SpinValue", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ac5bceaefcbcb0d8301444ff405dbfa86", null ],
    [ "SpinValueMax", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a78b4d1b868116e6e732dfc9c0b0290d7", null ],
    [ "SpinValueMin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a17efccdcd1e554e36ce7f046eef395f2", null ],
    [ "SymbolColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a9869d178a856012e763c93fa1e9d83a6", null ]
];

==> libreoffice-fresh-sdk-25.8.4-2-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.js <==
var servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel =
[
    [ "com::sun::star::awt::UnoControlModel", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ac1ee7df8246117083090d716cae44bb0", null ],
    [ "BackgroundColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a85c9847c6ec77e673c618e26b2aa0746", null ],
    [ "Border", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a54d3ff280d892218d71e667f81ce99d4", null ],
    [ "BorderColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a79f9492eb784a2ae0323d4d31b179a8a", null ],
    [ "Enabled", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#add0e09d5a83268ea58802b8b35fb4dfa", null ],
    [ "HelpText", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a7e52ef40b5265c017585bf7d607ee31a", null ],
    [ "HelpURL", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a755e2d2c27383c5201ee98aaed028954", null ],
    [ "MouseWheelBehavior", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#aa612def382bea69d1c4e47f279268ae2", null ],
    [ "Orientation", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#af0ee8cde7520951ddb159c25b871f626", null ],
    [ "Printable", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ad75a741ee6d8f45340ba0bbb7771f05b", null ],
    [ "Repeat", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a5129b8c2bd73916407e626738bd0136b", null ],
    [ "RepeatDelay", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a4e2dfbf3068c08b49a036a8490722569", null ],
    [ "SpinIncrement", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a854bc2fd59eb64624028d76321994d70", null ],
    [ "SpinValue", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#ac5bceaefcbcb0d8301444ff405dbfa86", null ],
    [ "SpinValueMax", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a78b4d1b868116e6e732dfc9c0b0290d7", null ],
    [ "SpinValueMin", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a17efccdcd1e554e36ce7f046eef395f2", null ],
    [ "SymbolColor", "servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html#a9869d178a856012e763c93fa1e9d83a6", null ]
];
